@@ -262,6 +262,30 @@ func runNew(args newArgs) error {
 		return fmt.Errorf("saving project: %w", err)
 	}
 
+	if proj.Runtime.Name() == "yaml" {
+		projFile := filepath.Join(root, "Pulumi.yaml")
+		f, err := ioutil.ReadFile(projFile)
+		if err != nil {
+			return fmt.Errorf("could not find Pulumi.yaml: %w", err)
+		}
+		appendFileName := "Pulumi.yaml.append"
+		appendFile := filepath.Join(root, appendFileName)
+		m, err := ioutil.ReadFile(appendFile)
+		if err == nil {
+			f = append(f, m...)
+			err = ioutil.WriteFile(projFile, f, 0600)
+			if err != nil {
+				return fmt.Errorf("failed to write %s: %w", projFile, err)
+			}
+			err = os.Remove(appendFile)
+			if err != nil {
+				return fmt.Errorf("could not remove %s: %w", appendFileName, err)
+			}
+		} else if !os.IsNotExist(err) {
+			return fmt.Errorf("could not get %s: %w", appendFileName, err)
+		}
+	}
+
 	// Create the stack, if needed.
 	if !args.generateOnly && s == nil {
 		if s, err = promptAndCreateStack(args.prompt,
