@@ -45,16 +45,5 @@ func TestPendingOperationsDeployment(t *testing.T) {
 	})
 
 	_, err := NewDeployment(&plugin.Context{}, &Target{}, snap, nil, &fixedSource{}, nil, false, nil)
-	if !assert.Error(t, err) {
-		t.FailNow()
-	}
-
-	invalidErr, ok := err.(PlanPendingOperationsError)
-	if !assert.True(t, ok) {
-		t.FailNow()
-	}
-
-	assert.Len(t, invalidErr.Operations, 1)
-	assert.Equal(t, resourceB.URN, invalidErr.Operations[0].Resource.URN)
-	assert.Equal(t, resource.OperationTypeCreating, invalidErr.Operations[0].Type)
+	assert.NoError(t, err)
 }
