@@ -1,4 +1,5 @@
-﻿// Copyright 2016-2019, Pulumi Corporation
+﻿// Copyright 2016-2022, Pulumi Corporation
+using System;
 
 namespace Pulumi
 {
@@ -20,12 +21,18 @@ namespace Pulumi
 
         #region common conversions
 
+        public static implicit operator InputUnion<T0, T1>(Union<T0, T1> value)
+            => Output.Create(value);
+
         public static implicit operator InputUnion<T0, T1>(T0 value)
             => Output.Create(value);
 
         public static implicit operator InputUnion<T0, T1>(T1 value)
             => Output.Create(value);
 
+        public static implicit operator InputUnion<T0, T1>(Output<Union<T0, T1>> value)
+            => new InputUnion<T0, T1>(value);
+
         public static implicit operator InputUnion<T0, T1>(Output<T0> value)
             => new InputUnion<T0, T1>(value.Apply(Union<T0, T1>.FromT0));
 
