@@ -187,6 +187,9 @@ Event: ${line}\n${e.toString()}`);
             if (opts.color) {
                 args.push("--color", opts.color);
             }
+            if (opts.plan) {
+                args.push("--plan", opts.plan);
+            }
         }
 
         let onExit = (hasError: boolean) => { return; };
@@ -299,6 +302,9 @@ Event: ${line}\n${e.toString()}`);
             if (opts.color) {
                 args.push("--color", opts.color);
             }
+            if (opts.plan) {
+                args.push("--save-plan", opts.plan);
+            }
         }
 
         let onExit = (hasError: boolean) => { return; };
@@ -747,6 +753,10 @@ export interface UpOptions {
     onEvent?: (event: EngineEvent) => void;
     program?: PulumiFn;
     color?: "always" | "never" | "raw" | "auto";
+    /**
+     * Plan specifies the path to an update plan to use for the update.
+     */
+    plan?: string;
 }
 
 /**
@@ -765,6 +775,10 @@ export interface PreviewOptions {
     onOutput?: (out: string) => void;
     onEvent?: (event: EngineEvent) => void;
     color?: "always" | "never" | "raw" | "auto";
+    /**
+     * Plan specifies the path where the update plan should be saved.
+     */
+    plan?: string;
 }
 
 /**
